@@ -86,7 +86,7 @@ def mTimeVersion(init_file):
     return d.strftime("%Y.%m.%d")
 
 
-def getVersionFromArchiveId(git_archive_id='$Format:%ct %d$'):
+def getVersionFromArchiveId(git_archive_id='1552145501  (HEAD -> master, tag: v2.1.0)'):
     """ Extract the tag if a source is from git archive.
 
         When source is exported via `git archive`, the git_archive_id init value is modified
@@ -251,7 +251,7 @@ class BuildPyCommand(setuptools.command.build_py.build_py):
 
     def run(self):
         self.run_command('build_js')
-        setuptools.command.build_py.build_py.run(self)
+        super().run()
 
 
 class EggInfoCommand(setuptools.command.egg_info.egg_info):
@@ -259,7 +259,7 @@ class EggInfoCommand(setuptools.command.egg_info.egg_info):
 
     def run(self):
         self.run_command('build_js')
-        setuptools.command.egg_info.egg_info.run(self)
+        super().run()
 
 
 def setup_www_plugin(**kw):
